==> kompas_scraper-1.0.0.tar.gz: kompas_scraper-1.0.0/README.md <==
### Title

kompas Scraper

### Descrption

* With kompas Scraper you can scrape search results and extract the contents produced by the search result.
* In kompas scraper it will scrape the data present of the website and give json data which contains the details of the contents on the website.

### JSON sample data
```sh
{
    "Scraper_repeat_data_0": [
        {
            "trenLatest_item": [
                {
                    "link": "https://health.kompas.com/read/2021/11/10/120000368/punya-gejala-mirip-ini-beda-bronkitis-dan-pneumonia",
                    "text": "\n\n\n\n\n\n\nHEALTH\n10/11/2021, 12:00 WIB\n\nPunya Gejala Mirip, Ini Beda Bronkitis dan Pneumonia\n\n\n"
                },
                {
                    "link": "https://health.kompas.com/read/2021/11/10/103100268/apa-beda-nyeri-dada-karena-gerd-dan-serangan-jantung-",
                    "text": "\n\n\n\n\n\n\nHEALTH\n10/11/2021, 10:31 WIB\n\nApa Beda Nyeri Dada karena GERD dan Serangan Jantung?\n\n\n"
                },
                {
                    "link": "https://health.kompas.com/read/2021/11/10/090100968/6-ciri-ciri-hamil-anak-kembar",
                    "text": "\n\n\n\n\n\n\nHEALTH\n10/11/2021, 09:01 WIB\n\n6 Ciri-ciri Hamil Anak Kembar\n\n\n"
                }
            ]
        }
```

[Click Here for more](https://datakund-scraper.s3.amazonaws.com/datakund_FQ23REN0TVW4ZPL_json.json)

### Run Scraper
```sh
from kompas_scraper import *
link="https://www.kompas.com/food"
data=run_kompas_scraper(link)
```

### How it works?
* It takes URL of kompas page with a search keyword to scrape the data.
* It generates the json data which contains the information of the kompas search result.
* It gives the every detail present inside website in the form of json data.


### Examples
Below are some of the examples of URLs using which you can scrape:

* [Example 1](https://www.kompas.com/food)

* [Example2](https://health.kompas.com/)


### Queries/ Feedback
If you have some queries or feedback please contact us at following    
[Telegram](https://t.me/datakund)  
[Email](abhishek@datakund.com)

==> kompas_scraper-1.0.1.tar.gz: kompas_scraper-1.0.1/README.md <==
### Title

Kompas Scraper

### Descrption

* With kompas Scraper you can scrape search results and extract the contents produced by the search result.
* In kompas scraper it will scrape the data present of the website and give json data which contains the details of the contents on the website.
* The scraper gives information of the title of the article, article content, links, publish date etc.

### JSON sample data
```sh
{
    "Scraper_repeat_data_0": [
        {
            "trenLatest_item": [
                {
                    "link": "https://health.kompas.com/read/2021/11/10/120000368/punya-gejala-mirip-ini-beda-bronkitis-dan-pneumonia",
                    "text": "\n\n\n\n\n\n\nHEALTH\n10/11/2021, 12:00 WIB\n\nPunya Gejala Mirip, Ini Beda Bronkitis dan Pneumonia\n\n\n"
                },
                {
                    "link": "https://health.kompas.com/read/2021/11/10/103100268/apa-beda-nyeri-dada-karena-gerd-dan-serangan-jantung-",
                    "text": "\n\n\n\n\n\n\nHEALTH\n10/11/2021, 10:31 WIB\n\nApa Beda Nyeri Dada karena GERD dan Serangan Jantung?\n\n\n"
                },
                {
                    "link": "https://health.kompas.com/read/2021/11/10/090100968/6-ciri-ciri-hamil-anak-kembar",
                    "text": "\n\n\n\n\n\n\nHEALTH\n10/11/2021, 09:01 WIB\n\n6 Ciri-ciri Hamil Anak Kembar\n\n\n"
                }
            ]
        }
```

[Download full sample data](https://datakund-scraper.s3.amazonaws.com/datakund_FQ23REN0TVW4ZPL_json.json)

### Run Scraper
```sh
from kompas_scraper import *
link="https://www.kompas.com/food"
data=run_kompas_scraper(link)
```

### How it works?
* It takes URL of kompas page with a search keyword to scrape the data.
* It generates the json data which contains the information of the kompas search result.


### Examples
Below are some of the examples of URLs using which you can scrape:

* [Example 1](https://www.kompas.com/food)

* [Example2](https://health.kompas.com/)


### Queries/ Feedback
If you have some queries or feedback please contact us at following    
[Telegram](https://t.me/datakund)  
[Email](abhishek@datakund.com)
